searchData={"items":[{"type":"module","doc":"Runs a set of components and is a component itself, meaning that a composite has the same interface - it accepts flow as input and returns a modified flow.","title":"Strom.Composite","ref":"Strom.Composite.html"},{"type":"module","doc":"iex> alias Strom.{Composite, Transformer, Splitter, Source, Sink}\n    iex> transformer = Transformer.new(:s, &(&1 + 1))\n    iex> splitter = Splitter.new(:s, %{odd: &(rem(&1, 2) == 1), even: &(rem(&1, 2) == 0)})\n    iex> composite = [transformer, splitter] |> Composite.new() |> Composite.start()\n    iex> source = :s |> Source.new([1, 2, 3]) |> Source.start()\n    iex> %{odd: odd, even: even} = %{} |> Source.call(source) |> Composite.call(composite)\n    iex> {Enum.to_list(odd), Enum.to_list(even)}\n    {[3], [2, 4]}","title":"Example - Strom.Composite","ref":"Strom.Composite.html#module-example"},{"type":"module","doc":"iex> alias Strom.{Composite, Transformer, Splitter, Source, Sink}\n    iex> transformer = Transformer.new(:s, &(&1 + 1))\n    iex> splitter = Splitter.new(:s, %{odd: &(rem(&1, 2) == 1), even: &(rem(&1, 2) == 0)})\n    iex> c1 = Composite.new([transformer])\n    iex> c2 = Composite.new([splitter])\n    iex> source = Source.new(:s, [1, 2, 3])\n    iex> composite = [source, c1, c2] |> Composite.new() |> Composite.start()\n    iex> %{odd: odd, even: even} = %{} |> Composite.call(composite)\n    iex> {Enum.to_list(odd), Enum.to_list(even)}\n    {[3], [2, 4]}","title":"Composites can be created from other composites - Strom.Composite","ref":"Strom.Composite.html#module-composites-can-be-created-from-other-composites"},{"type":"function","doc":"","title":"Strom.Composite.call/2","ref":"Strom.Composite.html#call/2"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Strom.Composite.child_spec/1","ref":"Strom.Composite.html#child_spec/1"},{"type":"function","doc":"","title":"Strom.Composite.component_supervisor_name/1","ref":"Strom.Composite.html#component_supervisor_name/1"},{"type":"function","doc":"","title":"Strom.Composite.components/1","ref":"Strom.Composite.html#components/1"},{"type":"function","doc":"","title":"Strom.Composite.delete/2","ref":"Strom.Composite.html#delete/2"},{"type":"function","doc":"","title":"Strom.Composite.delete/3","ref":"Strom.Composite.html#delete/3"},{"type":"function","doc":"","title":"Strom.Composite.insert/3","ref":"Strom.Composite.html#insert/3"},{"type":"function","doc":"","title":"Strom.Composite.new/2","ref":"Strom.Composite.html#new/2"},{"type":"function","doc":"","title":"Strom.Composite.registry_name/1","ref":"Strom.Composite.html#registry_name/1"},{"type":"function","doc":"","title":"Strom.Composite.start/1","ref":"Strom.Composite.html#start/1"},{"type":"function","doc":"","title":"Strom.Composite.start_components/2","ref":"Strom.Composite.html#start_components/2"},{"type":"function","doc":"","title":"Strom.Composite.start_link/1","ref":"Strom.Composite.html#start_link/1"},{"type":"function","doc":"","title":"Strom.Composite.stop/1","ref":"Strom.Composite.html#stop/1"},{"type":"type","doc":"","title":"Strom.Composite.t/0","ref":"Strom.Composite.html#t:t/0"},{"type":"function","doc":"","title":"Strom.Composite.task_supervisor_name/1","ref":"Strom.Composite.html#task_supervisor_name/1"},{"type":"module","doc":"DSL for building components","title":"Strom.DSL","ref":"Strom.DSL.html"},{"type":"macro","doc":"","title":"Strom.DSL.mix/3","ref":"Strom.DSL.html#mix/3"},{"type":"macro","doc":"","title":"Strom.DSL.rename/1","ref":"Strom.DSL.html#rename/1"},{"type":"macro","doc":"","title":"Strom.DSL.sink/3","ref":"Strom.DSL.html#sink/3"},{"type":"macro","doc":"","title":"Strom.DSL.source/3","ref":"Strom.DSL.html#source/3"},{"type":"macro","doc":"","title":"Strom.DSL.split/3","ref":"Strom.DSL.html#split/3"},{"type":"macro","doc":"","title":"Strom.DSL.transform/4","ref":"Strom.DSL.html#transform/4"},{"type":"module","doc":"Generic functionality used by other components.","title":"Strom.GenMix","ref":"Strom.GenMix.html"},{"type":"function","doc":"","title":"Strom.GenMix.call/2","ref":"Strom.GenMix.html#call/2"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Strom.GenMix.child_spec/1","ref":"Strom.GenMix.html#child_spec/1"},{"type":"function","doc":"","title":"Strom.GenMix.process_chunk/4","ref":"Strom.GenMix.html#process_chunk/4"},{"type":"function","doc":"","title":"Strom.GenMix.send_to_tasks/2","ref":"Strom.GenMix.html#send_to_tasks/2"},{"type":"function","doc":"","title":"Strom.GenMix.start/1","ref":"Strom.GenMix.html#start/1"},{"type":"function","doc":"","title":"Strom.GenMix.start_link/1","ref":"Strom.GenMix.html#start_link/1"},{"type":"function","doc":"","title":"Strom.GenMix.state/1","ref":"Strom.GenMix.html#state/1"},{"type":"function","doc":"","title":"Strom.GenMix.stop/1","ref":"Strom.GenMix.html#stop/1"},{"type":"module","doc":"Mix several streams into one. Use Strom.GenMix under the hood","title":"Strom.Mixer","ref":"Strom.Mixer.html"},{"type":"module","doc":"iex> alias Strom.Mixer\n    iex> mixer = [:s1, :s2] |> Mixer.new(:stream) |> Mixer.start()\n    iex> flow = %{s1: [1, 2, 3], s2: [4, 5, 6]}\n    iex> %{stream: stream} = Mixer.call(flow, mixer)\n    iex> stream |> Enum.to_list() |> Enum.sort()\n    [1, 2, 3, 4, 5, 6]","title":"Example - Strom.Mixer","ref":"Strom.Mixer.html#module-example"},{"type":"function","doc":"","title":"Strom.Mixer.call/2","ref":"Strom.Mixer.html#call/2"},{"type":"type","doc":"","title":"Strom.Mixer.event/0","ref":"Strom.Mixer.html#t:event/0"},{"type":"function","doc":"","title":"Strom.Mixer.new/3","ref":"Strom.Mixer.html#new/3"},{"type":"function","doc":"","title":"Strom.Mixer.process_chunk/4","ref":"Strom.Mixer.html#process_chunk/4"},{"type":"function","doc":"","title":"Strom.Mixer.start/1","ref":"Strom.Mixer.html#start/1"},{"type":"function","doc":"","title":"Strom.Mixer.stop/1","ref":"Strom.Mixer.html#stop/1"},{"type":"type","doc":"","title":"Strom.Mixer.t/0","ref":"Strom.Mixer.html#t:t/0"},{"type":"module","doc":"Composite of mixers, use it when you need mixing a lot of streams","title":"Strom.MixerTree","ref":"Strom.MixerTree.html"},{"type":"type","doc":"","title":"Strom.MixerTree.event/0","ref":"Strom.MixerTree.html#t:event/0"},{"type":"function","doc":"","title":"Strom.MixerTree.new/3","ref":"Strom.MixerTree.html#new/3"},{"type":"module","doc":"Renames streams in flow.","title":"Strom.Renamer","ref":"Strom.Renamer.html"},{"type":"module","doc":"iex> alias Strom.Renamer\n    iex> flow = %{s1: [1], s2: [2]}\n    iex> renamer = %{s1: :foo1, s2: :foo2} |> Renamer.new() |> Renamer.start()\n    iex> Renamer.call(flow, renamer)\n    %{foo1: [1], foo2: [2]}","title":"Example - Strom.Renamer","ref":"Strom.Renamer.html#module-example"},{"type":"function","doc":"","title":"Strom.Renamer.call/2","ref":"Strom.Renamer.html#call/2"},{"type":"function","doc":"","title":"Strom.Renamer.new/1","ref":"Strom.Renamer.html#new/1"},{"type":"function","doc":"","title":"Strom.Renamer.start/1","ref":"Strom.Renamer.html#start/1"},{"type":"function","doc":"","title":"Strom.Renamer.stop/1","ref":"Strom.Renamer.html#stop/1"},{"type":"type","doc":"","title":"Strom.Renamer.t/0","ref":"Strom.Renamer.html#t:t/0"},{"type":"behaviour","doc":"Runs a given steam and `call` origin on each even in stream.\nBy default it runs the stream asynchronously (in `Task.async`).\nOne can pass `true` a the third argument to the `Sink.new/3` function to run a stream synchronously.","title":"Strom.Sink","ref":"Strom.Sink.html"},{"type":"behaviour","doc":"iex> alias Strom.{Sink, Sink.WriteLines}\n    iex> sink = :strings |> Sink.new(WriteLines.new(\"test/data/sink.txt\"), sync: true) |> Sink.start()\n    iex> %{} = Sink.call(%{strings: [\"a\", \"b\", \"c\"]}, sink)\n    iex> File.read!(\"test/data/sink.txt\")\n    \"a\\nb\\nc\\n\"\n\nSink defines a `@behaviour`. One can easily implement their own sinks.\nSee `Strom.Sink.Writeline`, `Strom.Sink.IOPuts`, `Strom.Sink.Null`","title":"Example - Strom.Sink","ref":"Strom.Sink.html#module-example"},{"type":"function","doc":"","title":"Strom.Sink.build_stream/2","ref":"Strom.Sink.html#build_stream/2"},{"type":"function","doc":"","title":"Strom.Sink.call/2","ref":"Strom.Sink.html#call/2"},{"type":"callback","doc":"","title":"Strom.Sink.call/2","ref":"Strom.Sink.html#c:call/2"},{"type":"type","doc":"","title":"Strom.Sink.event/0","ref":"Strom.Sink.html#t:event/0"},{"type":"function","doc":"","title":"Strom.Sink.new/3","ref":"Strom.Sink.html#new/3"},{"type":"function","doc":"","title":"Strom.Sink.process_chunk/4","ref":"Strom.Sink.html#process_chunk/4"},{"type":"function","doc":"","title":"Strom.Sink.start/1","ref":"Strom.Sink.html#start/1"},{"type":"callback","doc":"","title":"Strom.Sink.start/1","ref":"Strom.Sink.html#c:start/1"},{"type":"function","doc":"","title":"Strom.Sink.stop/1","ref":"Strom.Sink.html#stop/1"},{"type":"callback","doc":"","title":"Strom.Sink.stop/1","ref":"Strom.Sink.html#c:stop/1"},{"type":"type","doc":"","title":"Strom.Sink.t/0","ref":"Strom.Sink.html#t:t/0"},{"type":"module","doc":"Sink to IO","title":"Strom.Sink.IOPuts","ref":"Strom.Sink.IOPuts.html"},{"type":"function","doc":"","title":"Strom.Sink.IOPuts.new/2","ref":"Strom.Sink.IOPuts.html#new/2"},{"type":"module","doc":"Sink to nowhere","title":"Strom.Sink.Null","ref":"Strom.Sink.Null.html"},{"type":"function","doc":"","title":"Strom.Sink.Null.new/0","ref":"Strom.Sink.Null.html#new/0"},{"type":"module","doc":"Sink to file line by line","title":"Strom.Sink.WriteLines","ref":"Strom.Sink.WriteLines.html"},{"type":"function","doc":"","title":"Strom.Sink.WriteLines.new/2","ref":"Strom.Sink.WriteLines.html#new/2"},{"type":"behaviour","doc":"Produces stream of events.","title":"Strom.Source","ref":"Strom.Source.html"},{"type":"behaviour","doc":"iex> alias Strom.Source\n    iex> source = :numbers |> Source.new([1, 2, 3]) |> Source.start()\n    iex> %{numbers: stream} = Source.call(%{}, source)\n    iex> Enum.to_list(stream)\n    [1, 2, 3]","title":"Example with Enumerable - Strom.Source","ref":"Strom.Source.html#module-example-with-enumerable"},{"type":"behaviour","doc":"iex> alias Strom.{Source, Source.ReadLines}\n    iex> source = :numbers |> Source.new(ReadLines.new(\"test/data/numbers1.txt\")) |> Source.start()\n    iex> %{numbers: stream} = Source.call(%{}, source)\n    iex> Enum.to_list(stream)\n    [\"1\", \"2\", \"3\", \"4\", \"5\"]","title":"Example with file - Strom.Source","ref":"Strom.Source.html#module-example-with-file"},{"type":"behaviour","doc":"iex> alias Strom.{Source, Source.ReadLines}\n    iex> source1 = :numbers |> Source.new([1, 2, 3]) |> Source.start()\n    iex> source2 = :numbers |> Source.new(ReadLines.new(\"test/data/numbers1.txt\")) |> Source.start()\n    iex> %{numbers: stream} = %{} |> Source.call(source1) |> Source.call(source2)\n    iex> Enum.to_list(stream)\n    [1, 2, 3, \"1\", \"2\", \"3\", \"4\", \"5\"]\n\nSource defines a `@behaviour`. One can easily implement their own sources.\nSee `Strom.Source.ReadLines`, `Strom.Source.Events`, `Strom.Source.IOGets`","title":"If two sources are applied to one stream, the streams will be concatenated (Stream.concat/2) - Strom.Source","ref":"Strom.Source.html#module-if-two-sources-are-applied-to-one-stream-the-streams-will-be-concatenated-stream-concat-2"},{"type":"function","doc":"","title":"Strom.Source.build_stream/1","ref":"Strom.Source.html#build_stream/1"},{"type":"callback","doc":"","title":"Strom.Source.call/1","ref":"Strom.Source.html#c:call/1"},{"type":"function","doc":"","title":"Strom.Source.call/2","ref":"Strom.Source.html#call/2"},{"type":"type","doc":"","title":"Strom.Source.event/0","ref":"Strom.Source.html#t:event/0"},{"type":"function","doc":"","title":"Strom.Source.new/3","ref":"Strom.Source.html#new/3"},{"type":"function","doc":"","title":"Strom.Source.process_chunk/4","ref":"Strom.Source.html#process_chunk/4"},{"type":"function","doc":"","title":"Strom.Source.start/1","ref":"Strom.Source.html#start/1"},{"type":"callback","doc":"","title":"Strom.Source.start/1","ref":"Strom.Source.html#c:start/1"},{"type":"function","doc":"","title":"Strom.Source.stop/1","ref":"Strom.Source.html#stop/1"},{"type":"callback","doc":"","title":"Strom.Source.stop/1","ref":"Strom.Source.html#c:stop/1"},{"type":"type","doc":"","title":"Strom.Source.t/0","ref":"Strom.Source.html#t:t/0"},{"type":"module","doc":"Source for reading IO inputs","title":"Strom.Source.IOGets","ref":"Strom.Source.IOGets.html"},{"type":"function","doc":"","title":"Strom.Source.IOGets.new/0","ref":"Strom.Source.IOGets.html#new/0"},{"type":"module","doc":"Source for reading a file line by line","title":"Strom.Source.ReadLines","ref":"Strom.Source.ReadLines.html"},{"type":"function","doc":"","title":"Strom.Source.ReadLines.new/1","ref":"Strom.Source.ReadLines.html#new/1"},{"type":"module","doc":"Split a stream into several streams by applying given functions on events","title":"Strom.Splitter","ref":"Strom.Splitter.html"},{"type":"module","doc":"iex> alias Strom.Splitter\n    iex> outputs = %{s1: &(rem(&1, 2) == 0), s2: &(rem(&1, 2) == 1)}\n    iex> splitter = :stream |> Splitter.new(outputs) |> Splitter.start()\n    iex> %{s1: s1, s2: s2} = Splitter.call(%{stream: [1, 2, 3]}, splitter)\n    iex> {Enum.to_list(s1), Enum.to_list(s2)}\n    {[2], [1, 3]}","title":"Example - Strom.Splitter","ref":"Strom.Splitter.html#module-example"},{"type":"module","doc":"iex> alias Strom.Splitter\n    iex> splitter = :stream |> Splitter.new([:s1, :s2]) |> Splitter.start()\n    iex> %{s1: s1, s2: s2} = Splitter.call(%{stream: [1, 2, 3]}, splitter)\n    iex> {Enum.to_list(s1), Enum.to_list(s2)}\n    {[1, 2, 3], [1, 2, 3]}","title":"Can also just duplicate a stream - Strom.Splitter","ref":"Strom.Splitter.html#module-can-also-just-duplicate-a-stream"},{"type":"function","doc":"","title":"Strom.Splitter.call/2","ref":"Strom.Splitter.html#call/2"},{"type":"type","doc":"","title":"Strom.Splitter.event/0","ref":"Strom.Splitter.html#t:event/0"},{"type":"function","doc":"","title":"Strom.Splitter.new/3","ref":"Strom.Splitter.html#new/3"},{"type":"function","doc":"","title":"Strom.Splitter.process_chunk/4","ref":"Strom.Splitter.html#process_chunk/4"},{"type":"function","doc":"","title":"Strom.Splitter.start/1","ref":"Strom.Splitter.html#start/1"},{"type":"function","doc":"","title":"Strom.Splitter.stop/1","ref":"Strom.Splitter.html#stop/1"},{"type":"type","doc":"","title":"Strom.Splitter.t/0","ref":"Strom.Splitter.html#t:t/0"},{"type":"module","doc":"Transforms a stream or several streams.\nIt works as Stream.map/2 or Stream.transform/3.\n\n    ## `map` example:\n    iex> alias Strom.Transformer\n    iex> transformer = :numbers |> Transformer.new(&(&1*2)) |> Transformer.start()\n    iex> flow = %{numbers: [1, 2, 3]}\n    iex> %{numbers: stream} = Transformer.call(flow, transformer)\n    iex> Enum.to_list(stream)\n    [2, 4, 6]\n\n    ## `reduce` example:\n    iex> alias Strom.Transformer\n    iex> fun = fn el, acc -> {[el, acc], acc + 10} end\n    iex> transformer = :numbers |> Transformer.new(fun, 10) |> Transformer.start()\n    iex> flow = %{numbers: [1, 2, 3]}\n    iex> %{numbers: stream} = Transformer.call(flow, transformer)\n    iex> Enum.to_list(stream)\n    [1, 10, 2, 20, 3, 30]","title":"Strom.Transformer","ref":"Strom.Transformer.html"},{"type":"module","doc":"iex> alias Strom.Transformer\n    iex> transformer = [:s1, :s2] |> Transformer.new(&(&1*2)) |> Transformer.start()\n    iex> flow = %{s1: [1, 2, 3], s2: [4, 5, 6]}\n    iex> %{s1: s1, s2: s2} = Transformer.call(flow, transformer)\n    iex> {Enum.to_list(s1), Enum.to_list(s2)}\n    {[2, 4, 6], [8, 10, 12]}","title":"it can be applied to several streams: - Strom.Transformer","ref":"Strom.Transformer.html#module-it-can-be-applied-to-several-streams"},{"type":"type","doc":"","title":"Strom.Transformer.acc/0","ref":"Strom.Transformer.html#t:acc/0"},{"type":"function","doc":"","title":"Strom.Transformer.call/2","ref":"Strom.Transformer.html#call/2"},{"type":"type","doc":"","title":"Strom.Transformer.event/0","ref":"Strom.Transformer.html#t:event/0"},{"type":"type","doc":"","title":"Strom.Transformer.func/0","ref":"Strom.Transformer.html#t:func/0"},{"type":"function","doc":"","title":"Strom.Transformer.new/4","ref":"Strom.Transformer.html#new/4"},{"type":"function","doc":"","title":"Strom.Transformer.process_chunk/4","ref":"Strom.Transformer.html#process_chunk/4"},{"type":"function","doc":"","title":"Strom.Transformer.start/1","ref":"Strom.Transformer.html#start/1"},{"type":"function","doc":"","title":"Strom.Transformer.stop/1","ref":"Strom.Transformer.html#stop/1"},{"type":"type","doc":"","title":"Strom.Transformer.t/0","ref":"Strom.Transformer.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}